@@ -20,8 +20,6 @@
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 #  USA
 
-from __future__ import absolute_import, print_function
-
 from gi.repository import Gtk
 from gi.repository import Gdk, GdkX11
 from gi.repository import Gio
@@ -32,34 +30,39 @@ import uaclient.api.u.pro.packages.updates.v1 as ua
 GdkX11  # pyflakes
 
 import warnings
-warnings.filterwarnings("ignore", "Accessed deprecated property",
-                        DeprecationWarning)
+
+warnings.filterwarnings(
+    "ignore", "Accessed deprecated property", DeprecationWarning
+)
 
 import distro_info
 import fnmatch
 import os
 import subprocess
 import sys
-import time
 import threading
+import time
 from gettext import gettext as _
 
 import dbus
 import dbus.service
 from dbus.mainloop.glib import DBusGMainLoop
+
 DBusGMainLoop(set_as_default=True)
 
 from .UnitySupport import UnitySupport
-from .Dialogs import (DistUpgradeDialog,
-                      ErrorDialog,
-                      HWEUpgradeDialog,
-                      NeedRestartDialog,
-                      NoUpdatesDialog,
-                      NoUpgradeForYouDialog,
-                      PartialUpgradeDialog,
-                      StoppedUpdatesDialog,
-                      UnsupportedDialog,
-                      UpdateErrorDialog)
+from .Dialogs import (
+    DistUpgradeDialog,
+    ErrorDialog,
+    HWEUpgradeDialog,
+    NeedRestartDialog,
+    NoUpdatesDialog,
+    NoUpgradeForYouDialog,
+    PartialUpgradeDialog,
+    StoppedUpdatesDialog,
+    UnsupportedDialog,
+    UpdateErrorDialog,
+)
 from .MetaReleaseGObject import MetaRelease
 from .UpdatesAvailable import UpdatesAvailable
 from .Core.AlertWatcher import AlertWatcher
@@ -67,16 +70,15 @@ from .Core.MyCache import MyCache
 from .Core.roam import NetworkManagerHelper
 from .Core.UpdateList import UpdateList
 from .Core.utils import get_arch, get_dist, SoftwarePropertiesPage
-from .backend import (InstallBackend,
-                      get_backend)
+from .backend import InstallBackend, get_backend
 
 # file that signals if we need to reboot
 REBOOT_REQUIRED_FILE = "/var/run/reboot-required"
 
 
 class UpdateManager(Gtk.Window):
-    """ This class is the main window and work flow controller. The main
-        window will show panes, and it will morph between them. """
+    """This class is the main window and work flow controller. The main
+    window will show panes, and it will morph between them."""
 
     def __init__(self, datadir, options):
         Gtk.Window.__init__(self)
@@ -102,9 +104,9 @@ class UpdateManager(Gtk.Window):
 
         # Keep window at a constant size
         ctx = self.get_style_context()
-        self.style_changed = ctx.connect("changed",
-                                         lambda ctx:
-                                             self.resize_to_standard_width())
+        self.style_changed = ctx.connect(
+            "changed", lambda ctx: self.resize_to_standard_width()
+        )
 
         # Signals
         self.connect("delete-event", self._on_close)
@@ -119,13 +121,15 @@ class UpdateManager(Gtk.Window):
             self.set_urgency_hint(True)
             self.unity.set_urgency(True)
             self.initial_focus_id = self.connect(
-                "focus-in-event", self.on_initial_focus_in)
+                "focus-in-event", self.on_initial_focus_in
+            )
 
         # Look for a new release in a thread
         self.meta_release = MetaRelease(
             self.options and self.options.devel_release,
             self.options and self.options.use_proposed,
-            self.options and self.options.debug)
+            self.options and self.options.debug,
+        )
 
     def begin_user_resizable(self, stored_width=0, stored_height=0):
         self.set_resizable(True)
@@ -195,7 +199,7 @@ class UpdateManager(Gtk.Window):
         self.exit()
 
     def exit(self):
-        """ exit the application, save the state """
+        """exit the application, save the state"""
         self._start_pane(None)
         sys.exit(0)
 
@@ -244,10 +248,12 @@ class UpdateManager(Gtk.Window):
         if self.cache is None:
             return
 
-        pane = self._make_available_pane(self.cache.install_count
-                                         + self.cache.del_count,
-                                         os.path.exists(REBOOT_REQUIRED_FILE),
-                                         cancelled_update, error_occurred)
+        pane = self._make_available_pane(
+            self.cache.install_count + self.cache.del_count,
+            os.path.exists(REBOOT_REQUIRED_FILE),
+            cancelled_update,
+            error_occurred,
+        )
         self._start_pane(pane)
 
     def _check_oem_metapackages(self):
@@ -256,31 +262,26 @@ class UpdateManager(Gtk.Window):
         lts = di.is_lts(codename)
         if not lts:
             return None
-        OEM_PATH = os.path.join(GLib.get_user_runtime_dir(),
-                                "ubuntu-drivers-oem.package-list")
+        OEM_PATH = os.path.join(
+            GLib.get_user_runtime_dir(), "ubuntu-drivers-oem.package-list"
+        )
         if not os.path.exists(OEM_PATH):
             return None
 
         # Packages that aren't installed but apply to this system
-        with open(OEM_PATH, 'r') as f:
+        with open(OEM_PATH, "r") as f:
             self.oem_metapackages |= set(f.read().splitlines())
 
         # Packages that are already installed
         for pkg in self.cache:
-            if fnmatch.fnmatch(pkg.name, 'oem-*-meta') \
-               and pkg.installed:
+            if fnmatch.fnmatch(pkg.name, "oem-*-meta") and pkg.installed:
                 self.oem_metapackages.add(pkg)
 
     def _fetch_ua_updates(self):
-        try:
-            self.ua_updates = ua.updates().updates
-        except Exception as e:
-            print("Error running updates end-point: ", e)
-            self.ua_updates = []
+        self.ua_updates = ua.updates().updates
 
     def _get_ua_security_status(self):
         self.ua_security_packages = []
-        self.ua_updates = []
         t = threading.Thread(target=self._fetch_ua_updates, daemon=True)
         t.start()
         while t.is_alive():
@@ -308,18 +309,24 @@ class UpdateManager(Gtk.Window):
                 )
         self.cache.create_pro_cache(self.ua_security_packages)
 
-    def _make_available_pane(self, install_count, need_reboot=False,
-                             cancelled_update=False, error_occurred=False):
+    def _make_available_pane(
+        self,
+        install_count,
+        need_reboot=False,
+        cancelled_update=False,
+        error_occurred=False,
+    ):
         self._check_hwe_support_status()
-        if install_count != 0:
+        if install_count != 0 or len(self.ua_security_packages) > 0:
             header = None
             desc = None
             if error_occurred:
                 desc = _("Some software couldn’t be checked for updates.")
             elif cancelled_update:
                 header = _("You stopped the check for updates.")
-                desc = _("Updated software is available from "
-                         "a previous check.")
+                desc = _(
+                    "Updated software is available from a previous check."
+                )
             # Display HWE updates first as an old HWE stack is vulnerable
             elif self.hwe_replacement_packages:
                 return HWEUpgradeDialog(self)
@@ -375,12 +382,14 @@ class UpdateManager(Gtk.Window):
 
         # Check for new fresh release
         settings = Gio.Settings.new("com.ubuntu.update-manager")
-        if (self.meta_release.new_dist
-                and (self.options.check_dist_upgrades
-                     or settings.get_boolean("check-dist-upgrades"))):
-            if self.arch == 'i386':
-                return NoUpgradeForYouDialog(self, self.meta_release,
-                                             self.arch)
+        if self.meta_release.new_dist and (
+            self.options.check_dist_upgrades
+            or settings.get_boolean("check-dist-upgrades")
+        ):
+            if self.arch == "i386":
+                return NoUpgradeForYouDialog(
+                    self, self.meta_release, self.arch
+                )
             return DistUpgradeDialog(self, self.meta_release)
 
         return None
@@ -417,9 +426,11 @@ class UpdateManager(Gtk.Window):
                 packages = e.output.strip().split()
                 self.hwe_replacement_packages = []
                 for pkgname in packages:
-                    pkgname = pkgname.decode('utf-8')
-                    if pkgname in self.cache and \
-                            not self.cache[pkgname].is_installed:
+                    pkgname = pkgname.decode("utf-8")
+                    if (
+                        pkgname in self.cache
+                        and not self.cache[pkgname].is_installed
+                    ):
                         self.hwe_replacement_packages.append(pkgname)
                 # for debugging
                 # print(self.hwe_replacement_packages)
@@ -439,19 +450,22 @@ class UpdateManager(Gtk.Window):
             self._start_pane(PartialUpgradeDialog(self))
             # we assert a clean cache
             header = _("Software index is broken")
-            desc = _("It is impossible to install or remove any software. "
-                     "Please use the package manager \"Synaptic\" or run "
-                     "\"sudo apt-get install -f\" in a terminal to fix "
-                     "this issue at first.")
+            desc = _(
+                "It is impossible to install or remove any software. "
+                'Please use the package manager "Synaptic" or run '
+                '"sudo apt-get install -f" in a terminal to fix '
+                "this issue at first."
+            )
             self.start_error(False, header, desc)
             return
         except SystemError as e:
             header = _("Could not initialize the package information")
-            desc = _("An unresolvable problem occurred while "
-                     "initializing the package information.\n\n"
-                     "Please report this bug against the 'update-manager' "
-                     "package and include the following error "
-                     "message:\n") + str(e)
+            desc = _(
+                "An unresolvable problem occurred while "
+                "initializing the package information.\n\n"
+                "Please report this bug against the 'update-manager' "
+                "package and include the following error message:\n"
+            ) + str(e)
             self.start_error(False, header, desc)
             return
 
@@ -459,6 +473,7 @@ class UpdateManager(Gtk.Window):
         def iterate():
             while Gtk.events_pending():
                 Gtk.main_iteration()
+
         iterate()
 
         self._check_oem_metapackages()
@@ -474,24 +489,27 @@ class UpdateManager(Gtk.Window):
 
         self.update_list = UpdateList(self)
         try:
-            self.update_list.update(self.cache, eventloop_callback=iterate,
-                                    duplicate_packages=self.duplicate_packages,
-                                    ua_security_packages=self.
-                                    ua_security_packages)
+            self.update_list.update(
+                self.cache,
+                eventloop_callback=iterate,
+                duplicate_packages=self.duplicate_packages,
+                ua_security_packages=self.ua_security_packages,
+            )
         except SystemError as e:
             header = _("Could not calculate the upgrade")
-            desc = _("An unresolvable problem occurred while "
-                     "calculating the upgrade.\n\n"
-                     "Please report this bug against the 'update-manager' "
-                     "package and include the following error "
-                     "message:\n") + str(e)
+            desc = _(
+                "An unresolvable problem occurred while "
+                "calculating the upgrade.\n\n"
+                "Please report this bug against the 'update-manager' "
+                "package and include the following error message:\n"
+            ) + str(e)
             self.start_error(True, header, desc)
 
         if self.update_list.distUpgradeWouldDelete > 0:
             self._start_pane(PartialUpgradeDialog(self))
 
     def _setup_dbus(self):
-        """ this sets up a dbus listener if none is installed already """
+        """this sets up a dbus listener if none is installed already"""
         # check if there is another g-a-i already and if not setup one
         # listening on dbus
         try:
@@ -500,36 +518,45 @@ class UpdateManager(Gtk.Window):
             print("warning: could not initiate dbus")
             return
         try:
-            proxy_obj = bus.get_object('org.freedesktop.UpdateManager',
-                                       '/org/freedesktop/UpdateManagerObject')
-            iface = dbus.Interface(proxy_obj,
-                                   'org.freedesktop.UpdateManagerIFace')
+            proxy_obj = bus.get_object(
+                "org.freedesktop.UpdateManager",
+                "/org/freedesktop/UpdateManagerObject",
+            )
+            iface = dbus.Interface(
+                proxy_obj, "org.freedesktop.UpdateManagerIFace"
+            )
             iface.bringToFront()
-            #print("send bringToFront")
+            # print("send bringToFront")
             sys.exit(0)
         except dbus.DBusException:
-            #print("no listening object (%s) " % e)
-            bus_name = dbus.service.BusName('org.freedesktop.UpdateManager',
-                                            bus)
+            # print("no listening object (%s) " % e)
+            bus_name = dbus.service.BusName(
+                "org.freedesktop.UpdateManager", bus
+            )
             self.dbusController = UpdateManagerDbusController(self, bus_name)
 
 
 class UpdateManagerDbusController(dbus.service.Object):
-    """ this is a helper to provide the UpdateManagerIFace """
-    def __init__(self, parent, bus_name,
-                 object_path='/org/freedesktop/UpdateManagerObject'):
+    """this is a helper to provide the UpdateManagerIFace"""
+
+    def __init__(
+        self,
+        parent,
+        bus_name,
+        object_path="/org/freedesktop/UpdateManagerObject",
+    ):
         dbus.service.Object.__init__(self, bus_name, object_path)
         self.parent = parent
         self.alert_watcher = AlertWatcher()
         self.alert_watcher.connect("network-alert", self._on_network_alert)
         self.connected = False
 
-    @dbus.service.method('org.freedesktop.UpdateManagerIFace')
+    @dbus.service.method("org.freedesktop.UpdateManagerIFace")
     def bringToFront(self):
         self.parent.present()
         return True
 
-    @dbus.service.method('org.freedesktop.UpdateManagerIFace')
+    @dbus.service.method("org.freedesktop.UpdateManagerIFace")
     def upgrade(self):
         try:
             self.parent.start_install()
